#
# spec file for package makemkv
#
# Copyright (c) 2020 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define majordriveio     0
%define libdriveio       libdriveio
%define libnamedriveio   %{libdriveio}%{majordriveio}
%define majormakemkv     1
%define libmakemkv       libmakemkv
%define libnamemakemkve  %{libmakemkv}%{majormakemkv}
%define majormmbd        0
%define libmmbd          libmmbd
%define libnamemmbd      %{libmmbd}%{majormmbd}

Name:           makemkv
Summary:        DVD and BlueRay Ripping tool
Version:        1.15.4
Release:        2.1
License:        Beerware
Group:          Productivity/Multimedia/Video/Editors and Convertors
Url:            http://www.makemkv.com
Source0:        %{name}-oss-%{version}.tar.gz
Source1:        %{name}-bin-%{version}.tar.gz
BuildRoot:      %{_tmppath}/%{name}-%{version}-%{release}-root
Requires:       %{libnamedriveio} = %{version}-%{release}
Requires:       %{libnamemakemkve} = %{version}-%{release}
Requires:       %{libnamemmbd} = %{version}-%{release}
BuildRequires:  libopenssl-devel
BuildRequires:  libexpat-devel
BuildRequires:  zlib-devel
BuildRequires:  pkgconfig(Qt5Core)
BuildRequires:  pkgconfig(Qt5DBus)
BuildRequires:  pkgconfig(Qt5Gui)
BuildRequires:  pkgconfig(Qt5Widgets)
BuildRequires:  pkgconfig(libavcodec)
BuildRequires:  pkgconfig(libavutil)
BuildRequires:  update-desktop-files
ExclusiveArch:  i586 x86_64

%description
MakeMKV is your one-click solution to convert video that you own into
free and patents-unencumbered format that can be played everywhere.
MakeMKV is a format converter, otherwise called "transcoder". It
converts the video clips from proprietary (and usually encrypted)
disc into a set of MKV files, preserving most information but not
changing it in any way. The MKV format can store multiple video/audio
tracks with all meta-information and preserve chapters. There are many
players that can play MKV files nearly on all platforms, and there are
tools to convert MKV files to many formats, including DVD and Blu-ray
discs.

Additionally MakeMKV can instantly stream decrypted video without
intermediate conversion to wide range of players, so you may watch
Blu-ray and DVD discs with your favorite player on your favorite OS
or on your favorite device. 

* Reads DVD and Blu-ray discs
* Reads Blu-ray discs protected with latest versions of AACS and BD+
* Preserves all video and audio tracks, including HD audio
* Preserves chapters information
* Preserves all meta-information (track language, audio type)
* Fast conversion - converts as fast as your drive can read data.
* No additional software is required for conversion or decryption.
* Available for Windows, Mac OS X and Linux
* Functionality to open DVD discs is free and will always stay free.
* All features (including Blu-ray decryption and processing) are free during BETA.


%package -n %{libnamedriveio}
Group:          System/Libraries
Summary:        MakeMKV %{libdriveio}
Provides:       %{libdriveio} = %{version}-%{release}

%description -n %{libnamedriveio}
MakeMKV %{libdriveio} shared library


%package -n %{libnamemakemkve}
Group:          System/Libraries
Summary:        MakeMKV %{libmakemkv}
Provides:       %{libmakemkv} = %{version}-%{release}

%description -n %{libnamemakemkve}
MakeMKV %{libmakemkv} shared library


%package -n %{libnamemmbd}
Group:          System/Libraries
Summary:        MakeMKV %{libmmbd}
Provides:       %{libmmbd} = %{version}-%{release}

%description -n %{libnamemmbd}
MakeMKV %{libmmbd} shared library


%prep
%setup -q -n %{name}-oss-%{version}

%build
%configure
%make_build

%install
%make_install
%suse_update_desktop_file -c makemkv makemkv "makemkv" makemkv makemkv.png AudioVideo AudioVideoEditing
tar xaf %{SOURCE1}
%ifarch x86_64
  %{__install} -m 755 %{name}-bin-%{version}/bin/amd64/makemkvcon %{buildroot}%{_bindir}/
%else
  %{__install} -m 755 %{name}-bin-%{version}/bin/i386/makemkvcon %{buildroot}%{_bindir}/
%endif

mkdir -p -m 755 %{buildroot}%{_datadir}/MakeMKV
%{__install} -m 644 %{name}-bin-%{version}/src/share/* %{buildroot}%{_datadir}/MakeMKV/


%post -n %{libnamedriveio} -p /sbin/ldconfig
%postun -n %{libnamedriveio} -p /sbin/ldconfig

%post -n %{libnamemakemkve} -p /sbin/ldconfig
%postun -n %{libnamemakemkve} -p /sbin/ldconfig

%post -n %{libnamemmbd} -p /sbin/ldconfig
%postun -n %{libnamemmbd} -p /sbin/ldconfig


%files
%doc %{name}-bin-%{version}/src/eula_en_linux.txt
%{_bindir}/*
%{_datadir}/MakeMKV
%{_datadir}/icons/hicolor
%{_datadir}/applications/makemkv.desktop

%files -n %{libnamedriveio}
%{_libdir}/%{libdriveio}.so.%{majordriveio}*

%files -n %{libnamemakemkve}
%{_libdir}/%{libmakemkv}.so.%{majormakemkv}*

%files -n %{libnamemmbd}
%{_libdir}/%{libmmbd}.so.%{majormmbd}*


%changelog
* Sat Dec 12 2020 manfred.h@gmx.net
- Update to version 1.15.4
  * Improved handling for discs with mastering errors
  * Many internal improvements and small bugfixes
  * Implemented seamless joining of TrueHD streams with overlapping
    frames based on Dominik Mydlil's idea
  * MakeMKV now recognizes and converts double-track Dolby Vision MKV files
  * Bug fixes:
  - Program could fail when processing TrueHD streams from MKV file
  - DTS core was not extracted from DTS-HD streams (1.15.0 regression)
* Sun Oct 11 2020 neutrino8@opensuse.org
- Update to version 1.15.3
  * Massive internal rewrite, many bugfixes
  * Improved handling for discs with mastering errors
  * Brand new network code, it is now possible to set proxy server
    in preferences, to access network over TOR/VPN
  * MakeMKV now can extract Dolby Vision metadata from elementary
    stream data and rebuild missing or invalid DV descriptors
  * Drive speed control update - MakeMKV now forces low speed when
    reading data around disc edges, working around firmware bugs
  * Bug fixes:
  - Program could hang or crash when converting files with
    many audio streams
  - On some multi-segment sources with LPCM audio program
    failed to produce MKV file
  - Program could crash when producing testdump or when conversion
    failed
  - On 32-bit x86 system program could run out of memory on big
    mult-segment sources
* Fri Jul 24 2020 neutrino8@opensuse.org
- Update to version 1.15.2
  * Massive internal rewrite, some improvements and small bugfixes
  * Muxer updated to the latest matroska specification
  * Advanced usage changes: Sdftool included as standalone executable
  * Drive speed control option
* Mon Apr 20 2020 neutrino8@opensuse.org
- Update to version 1.15.1
  * Added support for AACS v76 (for those poor souls without LibreDrive)
  * Improved handling for discs with mastering errors
  * Many internal improvements and small bugfixes
  * Bug fixes: For some HD audio streams frames were dropped incorrectly
    on segment boundaries
* Thu Mar  5 2020 neutrino8@opensuse.org
- Update to version 1.15.0
  * User interface update
  * New preferences page for LibMMBD integation
  * Improved handling for discs with mastering errors
  * Better tolerance for corrupted input data
  * Many internal improvements
* Tue Jan 28 2020 neutrino8@opensuse.org
- Update libavcodec/libavutil macro for Tumbleweed
* Fri Dec  6 2019 neutrino8@opensuse.org
- Update to version 1.14.7
  * Better compatibility for decrypted AACS 2.1 FMTS files
  * Fixed variable expansion bug for default file name template
  * Added support for AACS 2.1
  * Many small bugfixes and improvements
* Sun Sep  8 2019 neutrino8@opensuse.org
- Update to version 1.14.5
  * Some small miscellaneous improvements
* Sat Jun  8 2019 neutrino8@opensuse.org
- Update to version 1.14.4
  * Added support for AACS v70 (for those poor souls without LibreDrive)
  * Many small improvements, program should work a bit faster now
* Wed May 29 2019 aloisio@gmx.com
- Added missing zlib dependency
- Spec cleanup
* Wed Mar 13 2019 neutrino8@opensuse.org
- Update to version 1.14.3
  * Added support for AACS v68
  * Many small miscellaneous improvements
* Mon Dec 10 2018 neutrino8@opensuse.org
- Update to version 1.14.2
  * Support for BDAV AVCREC discs
  * Improved handling for DVD discs with mastering errors
  * Some small miscellaneous improvements
  * Bug fixes for 1.14.0 regressions:
    On DVD discs some titles could fail to open, sometimes even
    crashing the program
    Opening most 3D blu-ray discs could fail in both backup and MKV mode
  * Bug fixes:
    Program failed on interlaced h.264 video streams with exotic encoding
* Fri Nov 16 2018 neutrino8@opensuse.org
- Update to version 1.14.1
  * Bug fixes: MakeMKV could crash during non-decrypted full disc backup
    Some discs caused extensive reads and very slow operation at the start
    of MKV file creation
* Wed Nov  7 2018 neutrino8@opensuse.org
- Update to version 1.14.0
  * Added support for AACS v66
  * MakeMKV now extracts closed captions and saves them as text subtitles
  * New video processing engine, MakeMKV should be much more tolerant for
    MPEG files with errors (BDAV)
  * libmmbd: Added compatibility for late
* Wed Jul 25 2018 neutrino8@opensuse.org
- Update to version 1.12.3
  * Improved handling for discs with mastering errors
  * Improved handling for Japanese BDAV discs
  * Many small miscellaneous improvements
* Fri May  4 2018 olaf@aepfle.de
- Use ffmpeg3 versions of pkgconfig(libav*)
* Sat Apr 28 2018 neutrino8@opensuse.org
- Update to version 1.12.2
  * Added support for AACS v65
  * Improved handling for DVD and BDAV discs with mastering errors
  * Added support for DTS LBR (XSA) decoding
  * Bug fixes:
  * Hashed keys could be skipped randomly
  * Linux: Fixed compilation issues with newer openssl and ffmpeg
    libraries
  * Windows: Fixed broken dialogs on Windows XP
  * Various stability fixes
* Sun Feb  4 2018 neutrino8@opensuse.org
- Update to version 1.12.0
  * Internal bugfixes mostly for UHD issues
* Sat Jan 20 2018 neutrino8@opensuse.org
- Update to version 1.10.10
  * Added support for AACS v64
  * Many bugfixes affecting stability
* Tue Jan  9 2018 neutrino8@opensuse.org
- Update to version 1.10.9
  * Improved handling for DVD discs with mastering errors
  * Many small miscellaneous improvements
* Fri Jan  5 2018 neutrino8@opensuse.org
- Add profiles and translation files to /usr/share/MakeMKV
* Tue Nov 21 2017 neutrino8@opensuse.org
- Update to version 1.10.8
  * Added support for (non-encrypted) UHD discs
  * Added support for HEVC in MKV files
  * Improved support for discs with BD-Java protection
  * Many small miscellaneous improvements
  * Bug fixes: Restored compatibility with OS X 10.6
* Mon Sep  4 2017 neutrino8@opensuse.org
- Update to version 1.10.7
  * Improved support for discs with BD-Java protection
  * Updated BD+ engine
  * OS X: Fixed incompatibility with High Sierra
  * Small miscellaneous improvements
* Sun May 28 2017 neutrino8@opensuse.org
- Update to version 1.10.6
  * Added support for AACS v63
  * Updated BD+ engine
  * Small miscellaneous improvements
  * Bug fixes: Program could hang with ASSERT on certain multi-segment
    titles
* Mon Mar 27 2017 neutrino8@opensuse.org
- Update to version 1.10.5
  * Improved handling for DVD discs with mastering errors
  * Better track AV sync management, especially for badly mastered discs
  * Small miscellaneous improvements
  * Bug fixes:
  * Program could crash randomly at the end of conversion
  * Opening HD-DVD disc with AC3/E-AC3 audio caused program to hang
  * Support for some BDAV discs was accidentally broken in 1.10.3
  * Fixed various build issues for OSS code
* Mon Jan  2 2017 neutrino8@opensuse.org
- Update to version 1.10.4
  * Program produced damaged MKV files if source was a 3D Blu-ray disc
  * Fixed various compilation issues for OSS code
* Tue Dec 13 2016 neutrino8@opensuse.org
- Update to version 1.10.3
  * Added support for DVD disc with broken VTS IFO files
    (used as structure protection)
  * Improved support for BD-Java discs
  * Updated BD+ engine
  * Small miscellaneous improvements
  * Bug fixes: "Auto" destination path was calculated incorrectly
    in 1.10.2
* Fri Oct 28 2016 neutrino8@gmail.com
- Update to version 1.10.2
* Tue Sep 22 2015 olaf@aepfle.de
- update to 1.9.5
- Use Qt5 on 13.2+
- Use pkgconfig for some BuildRequires
* Sat Dec 13 2014 joerg.lorenzen@ki.tng.de
- update to 1.9.0
    Added support for AACS v50
    Updated BD+ engine
    Improved handling for discs with mastering errors
    Small miscellaneous improvements
    Bug fixes:
    Regression in 1.8.14 - some discs with BD+ released in
    2010-2011 could fail to open
    Expert mode:
    Manual DVD mode - custom content selection, split titles
    by chapters
- version 1.8.14
    Added support for Dolby Atmos audio streams
    Updated BD+ engine
    Improved handling for discs with mastering errors
    Bug fixes:
    Program could crash on some DVD discs with incorrect structure
- version 1.8.13
    Added support for AACS v48
    Added support for DTS-HD streams with variable bit depth
    Improved handling for discs with mastering errors
    Bug fixes:
    Regression in 1.8.12 - program failed to process multi-channel
    LPCM audio
    Linux: lowered minimal required GLIBC version
- version 1.8.12
    Added support for LPCM streams with variable bit depth
    Improved handling for discs with mastering errors
    Better handling for partially damaged streams
    Bug fixes:
    FLAC audio streams with large frames were not supported
    Rarely, program could crash at the end of audio transcoding,
    usually when processing DTS-HD 7.1 audio
    Most of DTS-HD LBR (DTS express) streams failed to decode
    Very very rarely, video frames were silently dropped at
    segment boundaries
    DVD: some titles were incorrectly detected as fake
    Linux: crash on systems with certain glibc (SYSV hash tables)
    Moved changelog to file makemkv.changes
* Wed Jun 18 2014 Manfred.Tremmel@iiv.de
- update to 1.8.11
    Updated support for AACS v47
    Updated BD+ support
    Improved handling for discs with mastering errors
    Better handling for partially damaged streams
    Added support for decoding 16-bit DTS-HD MA streams
    Small miscellaneous improvements
    Bug fixes:
    MakeMKV could fail reading MKV files with compressed subtitles
    Occasionnaly, timecodes for B-frames were incorrect in
    produced MKV file
    DVD: rarely, some titles were incorrectly detected as fake
    Linux: MakeMKV could crash on systems with certain glibc (Gentoo)
    Libmmbd could fail to decrypt discs with old AACS protection
    Fixes for 1.8.10 regressions:
    Blu-ray: some (rare) multi-segment titles could produce error
    at the end of conversion
* Wed Apr 16 2014 Manfred.Tremmel@iiv.de
- update to 1.8.10
    Improved handling for discs with mastering errors
    Greatly improved conversion speed for multi-segment titles
    Small miscellaneous improvements
    Bug fixes:
    During streaming, program could crash randomly
    When changing preferences, program could crash randomly
    Fixes for 1.8.9 regressions:
    DVD: some titles were missing (incorrectly identified as fakes)
    Blu-ray: discs missing JAR directory failed to open
* Wed Feb 26 2014 Manfred.Tremmel@iiv.de
- update to 1.8.9
    Improved handling for DVD discs with mastering errors
    Small miscellaneous improvements
    Bug fixes:
    Linux: Added compatibility APIs to libmmbd
    Fixes for 1.8.8 regressions:
    "no filter" error for certain LPCM tracks
    MKV flags were not written to output file
* Sun Feb 23 2014 Manfred.Tremmel@iiv.de
- update to 1.8.8
    Improved handling for discs with mastering errors
    Many small miscellaneous improvements
    Bug fixes:
    A false "100%% hashckeck failed" error could show up on certain
    drive/disc combinations
    DVD: Discs with multichannel mpeg2-audio failed to open
    Linux: Added workaround for broken openssl library on
    RedHat-based distributions
    Expert mode: TrueHD transcoding could fail on streams with
    certain (rare) encoding
    Expert mode:
    Default selection rule now also applies to attachments,
    with new [+-]sel:attachment token
    Seamless sample-level joining for LPCM and transcoded audio tracks
    Audio mixing - channel and BPS downmix now can be set in profile
    Added support for AAC encoding (based on libfdk-aac: AAC-LC,
    HE-AAC and HE-AACv2 profiles)
    Added AAC-stereo conversion profile - allows converting any
    audio track to AAC stereo downmix in addition to saving
    the original track
    Improved display of transcoding settings
* Sat Dec 14 2013 Manfred.Tremmel@iiv.de
- update to 1.8.7
    Updated support for AACS v46
    Improved compatibility of produced MKV files
    Bug fixes:
    Linux: On some distributions MakeMKV could randomly hang on startup
* Mon Nov 11 2013 Manfred.Tremmel@iiv.de
- update to 1.8.6
    Improved handling for discs with mastering errors
    Improved compatibility with certain (rare) H.264 and VC-1 streams
    Mac OS X: MakeMKV can now open .dvdmedia bundles
    Mac OS X: DASPI v1.4 now supports OS X Mavericks
    Stability improvements
    Expert mode:
    MakeMKV no longer uses external ffmpeg binary
    Added support for AC3 encoding (mainly for DTS->AC3 audio transcoding)
    MMBD now emulates both old and latest libaacs/libbdplus API
    Bug fixes:
    Windows: Rarely, an external drive was not recognized by program
    Linux: Discs with special characters in volume name could fail to open
* Sat Sep 14 2013 Manfred.Tremmel@iiv.de
- update to 1.8.5
    Improved handling for discs with mastering errors
    Stability improvements
- version 1.8.4
    Improved handling for discs with mastering errors
    Many miscellaneous improvements
    Bug fixes:
    Rarely, some episodes could be missing on a series blu-rays
    When using audio transcoding, channel layout was incorrect for
    certain DTS-HD surround modes
    Default/forced flag profile settings were ignored after 1.8.2 changes
* Wed May 22 2013 Manfred.Tremmel@iiv.de
- update to 1.8.3
    Updated support for AACS v40
    Reduced memory usage during conversion
    Bug fixes:
    MakeMKV could crash when backing up an incorrectly mastered
    3D blu-ray disc
* Mon May 13 2013 Manfred.Tremmel@iiv.de
- update to 1.8.2
    Bug fixes:
    Randomly, MakeMKV could hang during eject, leaving console
    portion running in background
    Expert mode:
    MKV track flags may be changed in GUI
    Forced tracks may be automatically marked as default in
    conversion profile
    Navigation keys may be used in property editor
* Wed May  8 2013 bmwiedemann@opensuse.org
- update to 1.8.1
    Improved compatibility of produced MKV files
    Improved handling for DVD discs with mastering errors
    Visual enhancements for HiDPI displays
    Many miscellaneous improvements
    Bug fixes:
    Mac OS X - Randomly, a disc could be unrecognized if inserted
    while MakeMKV running
    Mac OS X / Linux - Eject button was not always working
    Audio transcoding could fail for certain DTS HD HRA tracks
    Chapter names were inconsistent for blu-ray discs
    Some (rare) MKV files couldn't be opened
    Expert mode:
    Chapter names may be changed in GUI
* Thu Feb 21 2013 Manfred.Tremmel@iiv.de
- update to 1.8.0
    Updated support for AACS v38
    Updated BD+ engine
    Added support for multi-angle blu-ray 3D
    Visual enhancements
    Improved compatibility of produced MKV files
    Italian translation
    Many miscellaneous stability improvements
    Bug fixes:
    Cover picture was always embedded into MKV file, even if not selected
    Failed to process some DVD with LPCM audio
    Saving to NFS volume on Linux could fail
    Expert mode:
    Additional profile settings
* Fri Jan  4 2013 Manfred.Tremmel@iiv.de
- update to 1.7.10
    Improved handling for DVD discs with mastering errors
    Many miscellaneous improvements
* Mon Nov  5 2012 Manfred.Tremmel@iiv.de
- update to 1.7.9
    Bug fixes:
    Audio transcoding could fail on Windows 7 under some circumstances
    MakeMKV no longer requires GLIBC 2.15 on Linux
    Few miscellaneous improvements
* Mon Oct 15 2012 Manfred.Tremmel@iiv.de
- update to 1.7.8
    Added support for AACS v35
    Updated BD+ engine
    Added ability to produce MKV files with compressed tracks (WDTV profile)
    Improved handling for DVD/Blu-ray discs with mastering errors
    Bug fixes:
    Audio transcoding could fail or hang at the very end of file
    MakeMKV could crash when reading DVDs with a specific structure protection
    Many miscellaneous stability improvements
* Mon Aug 27 2012 Manfred.Tremmel@iiv.de
- update to 1.7.7
    Improved handling for DVD/Blu-ray discs with mastering errors
    MakeMKV now prevents computer going to sleep mode during copy
    Miscellaneous stability improvements
    Max OS X changes:
    BDMV folder bundles can be selected on Mountain Lion
    Switched from GROWL to Mountain Lion notifications
    Expert mode:
    MakeMKV now includes ffmpeg executable with 24-bit FLAC encoder
    New FLAC profile
    Bug fixes:
    On some DVDs MakeMKV could go into endless loop when opening
    disc in CellWalk mode
    MakeMKV could hang (endless ASSERT) on titles with seamless
    branching and LPCM tracks
    Forced subtitles were extracted incompletely on certain blu-ray discs
    Aspect ratio was sometimes incorrect for H.264 SD content
    Occasionally makemkvcon executable could stay running in
    background even after application window was closed
* Sun Jul  1 2012 Manfred.Tremmel@iiv.de
- update to 1.7.6
    Added support for AACS v32
- version 1.7.5
    Miscellaneous stability and improvements
    Expert mode - support for DTS-HD decoding/transcoding
* Sat Apr 14 2012 Manfred.Tremmel@iiv.de
- update to 1.7.4
    Added support for AACS v31
    Improved handling for DVD/Blu-ray discs with mastering errors
    Conversion profile improvements in expert mode
    Bug fixes:
    On some discs 3D MVC video was not recognized
    Subtitle tracks were not available on HD-DVD discs after 1.7.0 update
- version 1.7.3
    Added ability to extract and put 3D MVC Video into MKV container
    Initial support for on-the-fly audio reencoding
    Improved functionality in expert mode
    Improved handling for DVD/Blu-ray discs with mastering errors
    Improved handling for DVD/Blu-ray discs with structure protection
    Better handling of MKV files created by other programs
    Many UI and stability improvements
    Bug fixes:
    MakeMKV could crash on profile change in expert mode
    A single audio frame could be incorrectly dropped at the start of file
    HD-DVD processing was accidentally broken in 1.7.0
* Wed Feb 15 2012 Manfred.Tremmel@iiv.de
- update to 1.7.2
    Added support for AACS v30
* Thu Feb  2 2012 Manfred.Tremmel@iiv.de
- update to 1.7.1
    Improved handling for Blu-ray discs with seamless branching
    Improved handling for DVD discs with mastering errors
    Improved handling for DVD discs with structure protection
    Expert mode:
    Profile can specify more complex default selection configurations
    Tracks order may be specified in profile and changed in GUI
    Bug fixes:
    MakeMKV could randomly crash in expert mode
    Rarely, some chapters could have been discarded from DVD disc
* Tue Jan 10 2012 Manfred.Tremmel@iiv.de
- update to 1.7.0
    Improved handling for Blu-ray with structure protection
    Improved handling for DVD discs with mastering errors
    Small performance improvements
    Expert mode:
    Many attributes of MKV file may be edited in GUI
    Output file name may be specified per title
    MakeMKV can output detailed AV synchronization statistics
    Arbitrary default track selection logic may be specified in profile
    Bug fixes:
    Short titles were incorrectly skipped on some DVDs
    On multi-angle DVDs chapters were not preserved for non-first angles
    Program could crash when processing Blu-ray discs with LPCM audio
    On some DVDs different titles were incorrectly marked as duplicates
    Some multi-angle or interleaved DVDs produced MKV files with
    noticeable AV synchronization issues
* Fri Oct 28 2011 Manfred.Tremmel@iiv.de
- update to 1.6.16
    Updated BD+ engine
    Added support for new DVD copy protections
    MakeMKV is now much more tolerant to DVD mastering errors
    Improved support for AVCHD discs
    Many stability improvements
    Bug fixes:
    Backup failed for blu-ray discs with DCOPY folder
    Some multi-angle DVDs were processed incorrectly
    Some DVDs could hang in CSS search phase
    Some DVDs could hang with code 2025 during conversion
- version 1.6.15
    Updated BD+ engine
    Added workarounds for incorrectly-mastered discs
    Miscellaneous bug fixes and stability improvements
* Thu Aug 18 2011 Manfred.Tremmel@iiv.de
- update to 1.6.14
    Bug fixes:
    MakeMKV was "stuck" when processing some blu-ray discs
    MakeMKV could randomly crash at start in rare cases
    Improved debug logging
    Miscellaneous stability improvements
- version 1.6.13
    Added support for AACS bus encryption
    Fixed failures on blu-ray discs with variable multi-angle playlists
    Added ability to open MKV files
    Various user interface improvements
    Many performance and stability improvements
    Bug fixes:
    Discs with LPCM audio could have failed occasionally
    Sparsely-encrypted discs could have failed
    No other fixes for submitted DVD and blu-ray reports, sorry
- version 1.6.12
    MKV engine fixes:
    Some MKV files produced from h.264 AVC blu-ray discs were not seekable
    Subtitles were displayed too short on some players
    Occasional errors on titles with forced subtitles
    Improved compatibility of produced MKV files
    Added workarounds for new DVD protections
    Miscellaneous stability and UI improvements
* Mon May 30 2011 Manfred.Tremmel@iiv.de
- update to 1.6.10
    Added support for AACS v25
    Fixed MKV multiplexing error introduced in 1.6.9
* Sun May 29 2011 Manfred.Tremmel@iiv.de
- update to 1.6.9
    Updated BD+ engine
    New MKV multiplexing engine
    Fixed occasional program errors on Mac OS X
    Fixed DASPI for Mac OS X 10.5.8
    Stability improvements
* Sun Apr 24 2011 Manfred.Tremmel@iiv.de
- update to 1.6.8
    Updated BD+ engine
    Workarounds for incorrectly-mastered discs
    Stability improvements
- version 1.6.7
    Added support for new DVD copy protections
    Workarounds for incorrectly-mastered discs
    Stability improvements
* Sun Apr  3 2011 Manfred.Tremmel@iiv.de
- update to 1.6.6
    Added support for AACS v23
    Workarounds for some incorrectly mastered discs
    Workarounds for external USB drives with JMicron chipset
    Miscellaneous stability and UI improvements
    Fixes:
    Disc access speed was very slow in some cases
    AACS auth could randomly fail on Linux
    Some discs failed to open with error "UpdateTrackInfo failed"
* Wed Feb 16 2011 Manfred.Tremmel@iiv.de
- update to 1.6.5
    Fixed several UI errors introduced in 1.6.4
    Miscellaneous stability and UI improvements
- version 1.6.4
    Improved conversion speed in most cases
    Improved handling for protected DVDs with episodic content
    Fixes:
    Some DVDs failed to open with error "Titleset #0 is invalid"
    Conversion failed with "code 15" at the end
    Max OS X changes:
    New disc access method - DASPI
    Overall UI improvements
    Growl notifications
    Miscellaneous stability improvements
- version 1.6.3
    Added support for AACS v20
    Updated BD+ engine
    Improved compatibility with incorrectly-encoded H.264 streams
    Improved processing for some DVDs
    Many stability improvements
* Sat Oct 30 2010 Manfred.Tremmel@iiv.de
- update to 1.6.2
    Improved processing for some DVDs
    Fixed occasional crashes introduced in 1.6.0
    Many stability improvements
- version 1.6.0
    Updated blu-ray keys for AACS v19
    Updated BD+ engine
    On backup MakeMKV now validates content hash tables and detects corrupted M2TS files
    Better support for DVD discs
    MakeMKV is now more tolerable to badly-mastered or damaged discs
    Better support for HD-DVD discs
    Many stability improvements
* Fri Aug  6 2010 Manfred.Tremmel@iiv.de
- update to 1.5.8
    Updated BD+ engine
    Added (optional) automatic checking for program and svq updates
    Miscellaneous stability improvements
* Sat Jul 17 2010 Manfred.Tremmel@iiv.de
- first spec file
